/* 
 * "ESCGLINE.H"
 * 
 * Part of The Escotia Playstation Library 
 *
 * Functions to make programming a chore not a pleasure
 *
 * Author:	ScoTT Campbell
 * Date:	10/9/98
 *
*/

#ifndef __ESCGLINEHEADER
#define __ESCGLINEHEADER



/******************************/
/* Start of GsGLINE functions */ 
/******************************/


void InitGLine(GsGLINE* linePtr, int xStart, int yStart, int xEnd, int yEnd);
/* Sets the line pointed to by linePtr start position to (xStart, yStart) and its'		*/
/* end position to (xEnd, yEnd)															*/
/* Its' attributes are set to no transparency and display on, and it's start and end	*/
/* colours are set to white and black respectively										*/


void SetGLinePosition(GsGLINE* linePtr, int xStart, int yStart, int xEnd, int yEnd);
/* Sets the line pointed to by linePtr to position (xStart,yStart), (xEnd,yEnd)			*/


void SetGLineStartPosition(GsGLINE* linePtr, int xStart, int yStart);
/* Sets the line pointed to by linePtr start position to (xStart,yStart)				*/


void SetGLineXStartPosition(GsGLINE* linePtr, int xStart);
/* Sets the line pointed to by linePtr start point X value to xStart					*/


void SetGLineYStartPosition(GsGLINE* linePtr, int yStart);
/* Sets the line pointed to by linePtr start point Y value to yStart					*/


void SetGLineEndPosition(GsGLINE* linePtr, int xEnd, int yEnd);
/* Sets the line pointed to by linePtr start position to (xStart,yStart)				*/


void SetGLineXEndPosition(GsGLINE* linePtr, int xEnd);
/* Sets the line pointed to by linePtr end point X value to xEnd						*/


void SetGLineYEndPosition(GsGLINE* linePtr, int yEnd);
/* Sets the line pointed to by linePtr end poit Y value to yEnd							*/


void MoveGLine(GsGLINE* linePtr, int xAmount, int yAmount);
/* Adjusts the line pointed to by linePtr x,y display position by the values			*/
/* xAmount,yAmount																		*/


void MoveGLineStart(GsGLINE* linePtr, int xAmount, int yAmount);
/* Adjusts the line pointed to by linePtr start positon by xAmount,yAmount				*/


void MoveGLineEnd(GsGLINE* linePtr, int xAmount, int yAmount);
/* Adjusts the line pointed to by linePtr end positon by xAmount,yAmount				*/


void SetGLineColourVectors(GsGLINE* linePtr, CVECTOR* startVectorPtr, CVECTOR* endVectorPtr);
/* Sets the line pointed to by linePtr start and end colours to the values in the		*/
/* colour vectors pointed to by startVectorPtr and endVectorPtr							*/


void SetGLineStartColourVector(GsGLINE* linePtr, CVECTOR* colourVectorPtr);
/* Sets the line pointed to by linePtr start colour to the value in the	colour vector 	*/
/* pointed to by startVectorPtr															*/


void SetGLineEndColourVector(GsGLINE* linePtr, CVECTOR* colourVectorPtr);
/* Sets the line pointed to by linePtr end colour to the value in the colour vector		*/
/* pointed to by endVectorPtr															*/


void SetGLineColours(GsGLINE* linePtr, unsigned char r0, unsigned char g0, unsigned char b0,
									   unsigned char r1, unsigned char g1, unsigned char b1);
/* Sets the line pointed to by linePtr start and end colours to the values(r0,g0,b0)	*/
/* and (r1,g1,b1) respectively															*/


void SetGLineStartColour(GsGLINE* linePtr, unsigned char r, unsigned char g, unsigned char b);
/* Sets the line pointed to by linePtr start colour to the value (r,g,b)   				*/


void SetGLineEndColour(GsGLINE* linePtr, unsigned char r, unsigned char g, unsigned char b);
/* Sets the line pointed to by linePtr end colour to the value (r,g,b)					*/


void SetGLineAttributes(GsGLINE* linePtr, unsigned long int attributes);
/* Sets the line pointed to by linePtr attributes to attributes as specifed in the Net	*/
/* Yaroze Manual																		*/


/****************************/
/* End of GsGLINE functions */ 
/****************************/

#endif