/* 
 * "ESCPIXEL.C"
 * 
 * Part of The Escotia Playstation Library 
 *
 * Functions to make programming a chore not a pleasure
 *
 * Author:	ScoTT Campbell
 * Date:	18/9/98
*/


#include "..\headers\escpixel.h"



/******************************/
/* Start of EsPIXEL functions */ 
/******************************/


void InitPixel(EsPIXEL* pixelPtr, int xPosition, int yPosition)
{
	pixelPtr->x = xPosition;
	pixelPtr->y = yPosition;

	pixelPtr->attribute = 0;
	pixelPtr->r = pixelPtr->g = pixelPtr->b = 255;

}/* InitPixel */



void SetPixelPosition(EsPIXEL* pixelPtr, int xPosition, int yPosition)
{
	pixelPtr->x = xPosition;
	pixelPtr->y = yPosition;

}/* SetPixelPosition */


void SetPixelXPosition(EsPIXEL* pixelPtr, int xPosition)
{
	pixelPtr->x = xPosition;

}/* SetPixelXPosition */


void SetPixelYPosition(EsPIXEL* pixelPtr, int yPosition)
{
	pixelPtr->y = yPosition;

}/* SetPixelYPosition */


void MovePixel(EsPIXEL* pixelPtr, int xAmount, int yAmount)
{
	pixelPtr->x += xAmount;
	pixelPtr->y += yAmount;

}/* MovePixel */


void SetPixelAttributes(EsPIXEL* pixelPtr, unsigned long int attributes)
{
	/* Clear top 4 bits */
	pixelPtr->attribute &= 0x0FFFFFFF;

	/* Set top 4 bits */
	pixelPtr->attribute |= attributes;

}/* SetPixelAttributes */


void SetPixelColourVector(EsPIXEL* pixelPtr, CVECTOR* colourVectorPtr)
{
	pixelPtr->r = colourVectorPtr->r;
	pixelPtr->g = colourVectorPtr->g;
	pixelPtr->b = colourVectorPtr->b;

}/* SetPixelColourVector */


void SetPixelColour(EsPIXEL* pixelPtr, unsigned char r, unsigned char g, unsigned char b)
{
	pixelPtr->r = r;
	pixelPtr->g = g;
	pixelPtr->b = b;

}/* SetPixelColour */


void EsSortPixel(EsPIXEL* pixelPtr, GsOT* otPtr, unsigned short int pri)
{
	GsLINE line;

	line.x0 = line.x1 = pixelPtr->x;
	line.y0 = line.y1 = pixelPtr->y;

	line.r = pixelPtr->r;
	line.g = pixelPtr->g;
	line.b = pixelPtr->b;

	line.attribute = pixelPtr->attribute;

	GsSortLine(&line, otPtr, pri);

}/* EsSortPixel */


/****************************/
/* End of EsPIXEL functions */ 
/****************************/